# Generated file
# - do not overwrite
# - do not include in git
from collections import namedtuple

BuildInfo = namedtuple(
    'BuildInfo',
    ['version', 'built_at', 'sha', 'branch', 'tag'],
)

BUILD_INFO = BuildInfo(
    version='v4.20.0~25af8c2',
    built_at='2025-07-01 08:19:45Z',
    sha='25af8c29d1d7d5e767dca72ce71d183b7434d751',
    branch='HEAD',
    tag='v4.20.0',
)
